@@ -97,12 +97,12 @@ static void mute_cb (GtkWidget *widget, channel_info *data);
 static void rec_cb (GtkWidget *widget, channel_info *data);
 static void adj_left_cb (GtkAdjustment *widget, channel_info *data);
 static void adj_right_cb (GtkAdjustment *widget, channel_info *data);
-static void help(GtkWidget *widget, gpointer data);
 static void about_cb (GtkWidget *widget, gpointer data);
 
 static void help_cb(GtkWidget *widget, gpointer data);
 static void fill_in_device_guis(GtkWidget *notebook);
 static void gmix_build_slidernotebook(void);
+static void gmix_hide_last_separator (void);
 
 /*
  * Gnome info:
@@ -112,7 +112,7 @@ GtkWidget  *slidernotebook;
 
 /* Menus */
 static GnomeUIInfo help_menu[] = {
-/*  	GNOMEUIINFO_ITEM_STOCK(N_("Help"), NULL, help, GNOME_STOCK_PIXMAP_HELP), */
+  	GNOMEUIINFO_ITEM_STOCK(N_("Help"), NULL, help_cb, GNOME_STOCK_PIXMAP_HELP),
 	GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
 	GNOMEUIINFO_END
 };
@@ -138,17 +138,13 @@ static GnomeUIInfo main_menu[] = {
 GList *devices;
 GHashTable *device_by_name = NULL;
 
-int mode=0, mode_norestore=0, mode_initonly=0, mode_nosave=0, num_mixers, mode_restore=0;
-#define M_NORESTORE	1
-#define M_INITONLY 	2
-#define M_NOSAVE	4
+static int num_mixers;
+static char *mixer_device = NULL;
 
 static const struct poptOption options[] = {
-	{"norestore", 'r', POPT_ARG_NONE, &mode_norestore, 0, N_("don't restore mixer-settings from configuration"), NULL},
-	{"restore", 'R', POPT_ARG_NONE, &mode_restore, 0, N_("restore mixer-settings from configuration"), NULL},
-	{"initonly", 'i', POPT_ARG_NONE, &mode_initonly, 0, N_("initialise the mixer(s) from stored configuration and exit"), NULL},
-	{"nosave", 's', POPT_ARG_NONE, &mode_nosave, 0, N_("don't save (modified) mixer-settings into configuration"), NULL},
-	{NULL, '\0', 0, NULL, 0}
+  { "device", '\0', POPT_ARG_STRING, &mixer_device,0,
+    N_("Mixer device to use"), NULL },
+  {NULL, '\0', 0, NULL, 0}
 };
 
 /*
@@ -164,18 +160,18 @@ static const struct poptOption options[] = {
 #define GNOME_STOCK_PIXMAP_BLANK NULL
 #endif
 struct pixmap device_pixmap[] = {
-	"Input Gain", GNOME_STOCK_PIXMAP_BLANK,
-	"PC Speaker", GNOME_STOCK_VOLUME,
-	"MIC", GNOME_STOCK_PIXMAP_BLANK,
-	"Line", GNOME_STOCK_LINE_IN,
-	"CD", GTK_STOCK_CDROM,
-	"Synth", GNOME_STOCK_PIXMAP_BLANK,
-	"PCM", GNOME_STOCK_PIXMAP_BLANK,
-	"Output Gain", GNOME_STOCK_PIXMAP_BLANK,
-	"Treble", GNOME_STOCK_PIXMAP_BLANK,
-	"Bass", GNOME_STOCK_PIXMAP_BLANK,
-	"Master", GNOME_STOCK_VOLUME,
-	"default", GNOME_STOCK_PIXMAP_BLANK,
+  "Input Gain", GNOME_STOCK_PIXMAP_BLANK,
+  "PC Speaker", GNOME_STOCK_VOLUME,
+  "MIC", GNOME_STOCK_PIXMAP_BLANK,
+  "Line", GNOME_STOCK_LINE_IN,
+  "CD", GTK_STOCK_CDROM,
+  "Synth", GNOME_STOCK_PIXMAP_BLANK,
+  "PCM", GNOME_STOCK_PIXMAP_BLANK,
+  "Output Gain", GNOME_STOCK_PIXMAP_BLANK,
+  "Treble", GNOME_STOCK_PIXMAP_BLANK,
+  "Bass", GNOME_STOCK_PIXMAP_BLANK,
+  "Master", GNOME_STOCK_VOLUME,
+  "default", GNOME_STOCK_PIXMAP_BLANK,
 };
 #else
 const char *device_labels[] = SOUND_DEVICE_LABELS;
@@ -184,42 +180,43 @@ const char *device_names[]  = SOUND_DEVICE_NAMES;
 #define GNOME_STOCK_PIXMAP_BLANK NULL
 #endif
 const char *device_pixmap[] = {
-	GNOME_STOCK_PIXMAP_VOLUME,               /* Master Volume */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Bass */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Treble */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Synth */
-	GNOME_STOCK_PIXMAP_BLANK,                /* PCM */
-	GNOME_STOCK_PIXMAP_VOLUME,               /* Speaker */
-	GNOME_STOCK_PIXMAP_LINE_IN,              /* Line In */
-	GNOME_STOCK_PIXMAP_MIC,                  /* Microphone */
-	GNOME_STOCK_PIXMAP_CDROM,                /* CD-Rom */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Recording monitor ? */
-	GNOME_STOCK_PIXMAP_BLANK,                /* ALT PCM */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Rec Level? */
-	GNOME_STOCK_PIXMAP_BLANK,                /* In Gain */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Out Gain */
-	GNOME_STOCK_PIXMAP_LINE_IN,              /* Aux 1 */
-	GNOME_STOCK_PIXMAP_LINE_IN,              /* Aux 2 */
-	GNOME_STOCK_PIXMAP_LINE_IN,              /* Line */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Digital 1 ? */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Digital 2 ? */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Digital 3 ? */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Phone in */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Phone Out */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Video */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Radio */
-	GNOME_STOCK_PIXMAP_BLANK,                /* Monitor (usually mic) vol */
-	GNOME_STOCK_PIXMAP_BLANK,                /* 3d Depth/space param */
-	GNOME_STOCK_PIXMAP_BLANK,                /* 3d center param */
-	GNOME_STOCK_PIXMAP_BLANK                 /* Midi */
+  GNOME_STOCK_PIXMAP_VOLUME,               /* Master Volume */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Bass */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Treble */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Synth */
+  GNOME_STOCK_PIXMAP_BLANK,                /* PCM */
+  GNOME_STOCK_PIXMAP_VOLUME,               /* Speaker */
+  GNOME_STOCK_PIXMAP_LINE_IN,              /* Line In */
+  GNOME_STOCK_PIXMAP_MIC,                  /* Microphone */
+  GNOME_STOCK_PIXMAP_CDROM,                /* CD-Rom */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Recording monitor ? */
+  GNOME_STOCK_PIXMAP_BLANK,                /* ALT PCM */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Rec Level? */
+  GNOME_STOCK_PIXMAP_BLANK,                /* In Gain */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Out Gain */
+  GNOME_STOCK_PIXMAP_LINE_IN,              /* Aux 1 */
+  GNOME_STOCK_PIXMAP_LINE_IN,              /* Aux 2 */
+  GNOME_STOCK_PIXMAP_LINE_IN,              /* Line */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Digital 1 ? */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Digital 2 ? */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Digital 3 ? */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Phone in */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Phone Out */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Video */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Radio */
+  GNOME_STOCK_PIXMAP_BLANK,                /* Monitor (usually mic) vol */
+  GNOME_STOCK_PIXMAP_BLANK,                /* 3d Depth/space param */
+  GNOME_STOCK_PIXMAP_BLANK,                /* 3d center param */
+  GNOME_STOCK_PIXMAP_BLANK                 /* Midi */
 };
+
 #endif
 
 #ifdef ALSA
 snd_mixer_callbacks_t read_cbs;
 
 static void rebuild_cb(void *data) {
-	fprintf(stderr, "gmix rebuild_cb()\n");
+        fprintf(stderr, "gmix rebuild_cb()\n");
 }
 
 static void element_cb(void *data, int cmd, snd_mixer_eid_t *eid) {
@@ -320,70 +317,77 @@ void config_cb(GtkWidget *widget, gpointer data)
 	prefs_make_window (app);
 };
 
+static void
+show_error (GtkDialog *dialog)
+{
+	char *text;
+
+	switch (gtk_dialog_run (dialog)) {
+	case 1:
+		text = g_strdup_printf (_("Volume control is unable to run correctly.\n\n"
+					  "Unable to open audio device '%s'.\n"
+					  "Please check that you have permissions to open '%s'\n"
+					  "and that you have sound support in your kernel.\n\n"
+					  "Press Quit to exit Volume control"), 
+					mixer_device, mixer_device);
+		gtk_label_set_text (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), text);
+		g_free (text);
+		gtk_dialog_set_response_sensitive (dialog, 1, FALSE);
+		show_error (dialog);
+		break;
+
+	default:
+		exit (0);
+	}
+}
+				    
 int
 main(int argc,
      char *argv[]) 
 {
-	mode = 0;
-
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-	gnome_init_with_popt_table("gnome-volume-control", VERSION,
-				   argc, argv, options,
-				   0, NULL);
+	gnome_program_init("gnome-volume-control", VERSION,
+			   LIBGNOMEUI_MODULE, argc, argv,
+			   GNOME_PARAM_POPT_TABLE, options,
+			   GNOME_PARAM_POPT_FLAGS, 0,
+			   GNOME_PARAM_APP_DATADIR, DATADIR, NULL);		
+	if (mixer_device == NULL) {
+		mixer_device = "/dev/mixer";
+	}
 
 	if (g_file_exists (GNOME_ICONDIR"/gnome-volume.png"))
 		gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-volume.png");
 	else
 		gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mixer.png");
 
-	if (mode_nosave) {
-		mode |= M_NOSAVE;
-	}
-	
-	if (mode_initonly) {
-		mode |= M_INITONLY;
-	}
-
 	scan_devices();
 	if (devices) {
-		if (~mode & M_INITONLY) {
-		        get_gui_config();
-			/* Beware boolean bastardization */
-			if (!prefs.set_mixer_on_start)
-				mode |= M_NORESTORE;
-			  
-		}
-		/* Command line always overrides */
-		if(mode_norestore) mode |= M_NORESTORE;
-		if(mode_restore) mode &= ~M_NORESTORE;
-
-/*  		if (~mode & M_NORESTORE) { */
+		get_gui_config();
+		/* Beware boolean bastardization */
 		get_device_config();
 		init_devices();
-/*  		}  */
-
-		if (~mode & M_INITONLY) {
-			open_dialog();
-		}
-
-/*  		if (~mode & M_NOSAVE) { */
+		
+		open_dialog();
 		put_device_config();
-/*  		} */
-
+		
 		free_devices();
 	} else {
-		GtkWidget *box;
-
-		box = gnome_error_dialog(_("I was not able to open your audio device.\n"
-					   "Please check that you have permission to open /dev/mixer\n"
-					   "and make sure you have sound support compiled into your kernel."));
-
-		gtk_signal_connect(GTK_OBJECT(box), "close",
-				   GTK_SIGNAL_FUNC(error_close_cb), NULL);
-		gtk_main();
+		GtkWidget *dialog;
+		
+		dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_NONE,
+						 _("Volume control is unable to run correctly.\n\n"
+						   "Press the details button for more details on the reasons for failure.\n\n"
+						   "Press Quit to quit Volume control"));
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("_Details"), 1, 
+					GTK_STOCK_QUIT, GTK_RESPONSE_CLOSE, NULL);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Invalid mixer device"));
+		show_error (dialog);
 	}
+
 	return 0;
 }
 
@@ -398,13 +402,32 @@ recsrc_from_channels (device_info *device)
 		channel_info *channel = c->data;
 
 		if (channel->is_record_source == TRUE) {
-			recsrc |= (channel->channel << 1);
+			recsrc |= (1 << channel->channel);
 		}
 	}
 
 	return recsrc;
 }
 
+static int
+open_mixer_device (const char *name,
+		   int device_num)
+{
+	char *device;
+	int fd;
+
+	if (device_num == 0) {
+		device = g_strdup (name);
+	} else {
+		device = g_strdup_printf ("%s%i", name, device_num);
+	}
+
+	fd = open (device, O_RDWR, 0);
+
+	g_free (device);
+	return fd;
+}
+
 static void
 set_channels_from_recsrc (device_info *device,
 			  int recsrc)
@@ -425,6 +448,11 @@ device_info *
 open_device (int num)
 {
 	device_info *new_device;
+	/*
+	 * This list is borrowed from GCONF_SOURCE/gconf/gconf.c
+	 */
+	gchar gconf_key_invalid_chars[] = " \t\r\n\"$&<>,+=#!()'|{}[]?~`;%\\";
+
 #ifdef ALSA
 	int device = 0, err; 
 	snd_mixer_info_t info; 
@@ -462,6 +490,7 @@ open_device (int num)
 	/* This is the name used thoughout all the config stuff
 	   Numerical part will probably change if you start adding more cards,
 	   screwing things up, but there's probably no way we can stop that. */
+	g_strdelimit (new_device->info.name, gconf_key_invalid_chars, '_');
 	new_device->card_name = g_strdup_printf ("alsa-%s-%d", new_device->info.name, num + 1);
 
 	if (!g_ascii_isalpha (new_device->info.name[0])) {
@@ -558,11 +587,10 @@ open_device (int num)
 	gdk_input_add (snd_mixer_file_descriptor(new_device->handle), GDK_INPUT_READ,
 		       read_mixer, new_device);
 #else
-	char device_name[255];
 	int res, ver, cnt;
 	/* Masks for the channel data - OSS blows compared to ALSA */
 	int recmask, recsrc, stereodee;
-	
+
 	/*
 	 * create new device configureation
 	 */
@@ -570,17 +598,21 @@ open_device (int num)
 	/*
 	 * open the mixer-device
 	 */
-	if (num == 0) {
-		sprintf (device_name, "/dev/mixer");
-	} else {
-		sprintf (device_name, "/dev/mixer%i", num);
-	}
 
-	new_device->fd = open (device_name, O_RDWR, 0);
-	
+	new_device->fd = open_mixer_device (mixer_device, num);
+
 	if (new_device->fd < 0) {
-		g_free (new_device);
-		return NULL;
+		/* If the supplied value didn't work try the default */
+		new_device->fd = open_mixer_device (mixer_device, num);
+
+		if (new_device->fd < 0) {
+			new_device->fd = open_mixer_device ("/dev/sound/mixer", num);
+		}
+
+		if (new_device->fd > 0) {
+			g_free (new_device);
+			return NULL;
+		}
 	}
 	
 	/*
@@ -619,7 +651,7 @@ open_device (int num)
 		return NULL;
 	}
 	
-	g_strdelimit (new_device->info.name, " ", '_');
+	g_strdelimit (new_device->info.name, gconf_key_invalid_chars, '_');
 	new_device->card_name = g_strdup_printf ("OSS-%s-%d", new_device->info.name, num + 1);
 	
 	if (!g_ascii_isalpha (new_device->info.name[0])) {
@@ -815,16 +847,13 @@ get_bool_with_default (const char *key,
 	value = gconf_client_get (client, key, NULL);
 	g_object_unref (G_OBJECT (client));
 	
-	g_print ("Result for %s is - ", key);
 	if (value != NULL) {
 		gboolean result;
 		
 		result = gconf_value_get_bool (value);
-		g_print ("%s\n", result ? "true" : "false");
 		gconf_value_free (value);
 		return result;
 	} else {
-		g_print ("%s (default)\n", default_result ? "true" : "false");
 		return default_result;
 	}
 }
@@ -840,17 +869,14 @@ get_int_with_default (const char *key,
 	value = gconf_client_get (client, key, NULL);
 	g_object_unref (G_OBJECT (client));
 
-	g_print ("Result for %s is - ", key);
 	if (value != NULL) {
 		int result;
 
 		result = gconf_value_get_int (value);
-		g_print ("%d\n", result);
 		gconf_value_free (value);
 		
 		return result;
 	} else {
-		g_print ("%d (default)\n", default_result);
 		return default_result;
 	}
 }
@@ -866,16 +892,13 @@ get_string_with_default (const char *key,
 	value = gconf_client_get (client, key, NULL);
 	g_object_unref (G_OBJECT (client));
 
-	g_print ("Result for %s is - ", key);
 	if (value != NULL) {
 		char *result;
 
 		result = g_strdup (gconf_value_get_string (value));
-		g_print ("%s\n", result);
 		gconf_value_free (value);
 		return result;
 	} else {
-		g_print ("%s (default)\n", default_result);
 		return g_strdup (default_result);
 	}
 }
@@ -898,13 +921,11 @@ get_one_device_config (gpointer a,
 		/* Check if the key base directory exists */
 		client = gconf_client_get_default ();
 		if (gconf_client_dir_exists (client, key_base, NULL) == FALSE) {
-			g_print ("%s does not exist\n", key_base);
 			g_free (key_base);
 			g_object_unref (G_OBJECT (client));
 			continue;
-		} else {
-			g_print ("Directory %s exists\n", key_base);
 		}
+		
 		g_object_unref (G_OBJECT (client));
 		
 		key = g_strdup_printf ("%s/title", key_base);
@@ -1135,37 +1156,37 @@ fill_in_device_guis (GtkWidget *notebook)
 			GtkWidget *label, *mixer, *separator;
 			GtkWidget *hbox;
 			channel_info *ci;
+			char *s;
 
 			ci = c->data;
 
-			hbox = gtk_hbox_new (FALSE, 2);
+			hbox = gtk_hbox_new (FALSE, 3);
 			gtk_widget_show (hbox);
 			
 			gtk_table_attach (GTK_TABLE (table), hbox, i, i+1,
-					  0, 1, GTK_EXPAND | GTK_FILL,
-					  GTK_FILL, 0, 0);
+					  0, 1, 0,
+					  GTK_FILL, 0, 3);
 			
 			if (ci->pixmap) {
 				spixmap = gtk_image_new_from_stock (ci->pixmap,
 								    GTK_ICON_SIZE_BUTTON);
 				gtk_box_pack_start (GTK_BOX (hbox), spixmap, FALSE, FALSE, 0);
-				if (prefs.show_icons == TRUE) {
-					gtk_widget_show (spixmap);
-				}
-				
+				gtk_widget_show (spixmap);
 				ci->icon = spixmap;
 			} else {
 				ci->icon = NULL;
 			}
 			
-			label = gtk_label_new (ci->user_title);
-			gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+			s = g_strdup_printf ("<span size=\"larger\">%s</span>",
+					     ci->user_title);
+			label = gtk_label_new (s);
+			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+			g_free (s);
+			gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
 			gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
 			gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 			
-			if (prefs.show_labels == TRUE) {
-				gtk_widget_show (label);
-			}
+			gtk_widget_show (label);
 			ci->label = label;
 
 			ci->mixer = make_slider_mixer(ci);
@@ -1263,7 +1284,7 @@ fill_in_device_guis (GtkWidget *notebook)
 			ci->separator = gtk_vseparator_new ();
 			gtk_table_attach (GTK_TABLE (table), ci->separator,
 					  i+1, i+2, 0, 6,
-					  GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+					  GTK_FILL, GTK_EXPAND | GTK_FILL, 2, 0);
 			gtk_widget_show (ci->separator);
 
 			if (ci->visible == FALSE) {
@@ -1293,6 +1314,7 @@ fill_in_device_guis (GtkWidget *notebook)
 		g_list_free (table_focus_chain);
 	}
 
+	gmix_hide_last_separator ();
 }
 
 void
@@ -1682,17 +1704,27 @@ adj_right_cb (GtkAdjustment *adjustment,
 }
 
 void 
-help(GtkWidget *widget, 
-     gpointer data)
+help_cb (GtkWidget *widget, 
+	 gpointer data)
 {
-	GnomeProgram *program;
 	GError *error = NULL;
-	gboolean ret;
 	
-	program = gnome_program_get ();
-        ret = gnome_help_display ("index.html", NULL, &error);
-	if (ret == FALSE) {
-		g_warning ("Error displaying document: %s", error->message);
+	gnome_help_display ("gnome-volume-control", NULL, &error);
+
+	if (error != NULL) {
+		GtkWidget *dialog;
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 ("There was an error displaying help: \n%s"),
+						 error->message);
+
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
 		g_error_free (error);
 	}
 }
@@ -1760,13 +1792,17 @@ gmix_change_channel (channel_info *ci,
 		}
 		
 		gtk_widget_show (ci->mute);
-		if (ci->icon != NULL) {
+		if (ci->icon != NULL && prefs.show_icons == TRUE) {
 			gtk_widget_show (ci->icon);
 		}
-		gtk_widget_show (ci->label);
+		if (prefs.show_labels == TRUE) {
+			gtk_widget_show (ci->label);
+		}
 	}
 
 	ci->visible = show;
+
+	gmix_hide_last_separator ();
 }
 		
 void
@@ -1825,4 +1861,24 @@ gmix_change_labels (gboolean show)
 	}
 }
 
+static void
+gmix_hide_last_separator (void)
+{
+	GList *d, *c;
+	gboolean hid = FALSE;
+	
+	for (d = devices; d; d = d->next) {
+		device_info *di = d->data;
+
+		for (c = g_list_last (di->channels); c; c = c->prev) {
+			channel_info *ci = c->data;
 		
+			if (ci->visible && hid == FALSE) {
+				gtk_widget_hide (ci->separator);
+				hid = TRUE;
+			} else if (ci->visible) {
+				gtk_widget_show (ci->separator);
+			}
+		}
+	}
+}
